@@ -415,8 +415,8 @@ end
 
 function driver:purge(username)
 	return engine:transaction(function()
-		local stmt,err = engine:delete("DELETE FROM \"prosody\" WHERE \"host\"=? AND \"user\"=?", host, username);
-		return true, err;
+		engine:delete("DELETE FROM \"prosody\" WHERE \"host\"=? AND \"user\"=?", host, username);
+		engine:delete("DELETE FROM \"prosodyarchive\" WHERE \"host\"=? AND \"user\"=?", host, username);
 	end);
 end
 
@@ -452,6 +452,8 @@ local function create_table(engine, name) -- luacheck: ignore 431/engine
 		Column { name="type", type="TEXT", nullable=false };
 		Column { name="value", type="MEDIUMTEXT", nullable=false };
 		Index { name="prosodyarchive_index", unique = true, "host", "user", "store", "key" };
+		Index { name="prosodyarchive_with_when", "host", "user", "store", "with", "when" };
+		Index { name="prosodyarchive_when", "host", "user", "store", "when" };
 	};
 	engine:transaction(function()
 		ProsodyArchiveTable:create(engine);
